@@ -30,6 +30,7 @@ bool can_display_unicode_string_function(const char *str, void *w);
 
 #define LOAD_APP_ICON(x) QIcon(":/icons/apps/scalable/" x ".svg")
 #define LOAD_ICON(x) load_icon(x, this)
+#define LOAD_COLORED_ICON(x) settings->loadColoredIcon(x, this)
 
 #define USE_QUOTES(arg, f) (arg && (arg->suggestsQuotes() || arg->type() == ARGUMENT_TYPE_TEXT) && f->id() != FUNCTION_ID_BASE && f->id() != FUNCTION_ID_BIN && f->id() != FUNCTION_ID_OCT && f->id() != FUNCTION_ID_DEC && f->id() != FUNCTION_ID_HEX)
 
@@ -54,6 +55,7 @@ bool contains_plot_or_save(const std::string &str);
 void base_from_string(std::string str, int &base, Number &nbase, bool input_base = false);
 long int get_fixed_denominator_qt(const std::string &str, int &to_fraction, const QString &localized_fraction, bool qalc_command = false);
 bool is_equation_solutions(const MathStructure &m);
+void fix_expression(std::string &str);
 
 #ifndef CLOCK_MONOTONIC
 #	define PREPARE_TIMECHECK(ms) \
@@ -100,6 +102,14 @@ enum {
 	CLEAR_EXPRESSION
 };
 
+enum {
+	HISTORY_EXPRESSION_TYPE_PARSED,
+	HISTORY_EXPRESSION_TYPE_ENTERED,
+	HISTORY_EXPRESSION_TYPE_ENTERED_AND_PARSED,
+	HISTORY_EXPRESSION_TYPE_PARSED_COMPACT,
+	HISTORY_EXPRESSION_TYPE_ENTERED_AND_PARSED_COMPACT
+};
+
 typedef enum {
 	SHORTCUT_TYPE_FUNCTION,
 	SHORTCUT_TYPE_FUNCTION_WITH_DIALOG,
@@ -239,6 +249,8 @@ class QalculateQtSettings : QObject {
 		void updateMessagePrintOptions();
 		void updateFavourites();
 		void setCustomAngleUnit();
+		void setDefaultCurrency();
+		QIcon loadColoredIcon(const QString &str, QWidget*);
 		bool checkExchangeRates(QWidget *parent);
 		void fetchExchangeRates(int timeout, int n = -1, QWidget *parent = NULL);
 		bool displayMessages(QWidget *parent);
@@ -264,15 +276,18 @@ class QalculateQtSettings : QObject {
 		PrintOptions printops;
 		bool complex_angle_form, dot_question_asked, implicit_question_asked, assumptions_warning_shown, adaptive_interval_display, tc_set, rpn_mode, chain_mode, caret_as_xor, ignore_locale, do_imaginary_j, fetch_exchange_rates_at_startup, always_on_top, display_expression_status, prefixes_default, rpn_keys, sinc_set;
 		bool automatic_digit_grouping;
+		bool custom_digit_grouping, custom_digit_group_changed;
+		std::string custom_digit_group_separator, custom_digit_group_format, saved_local_dgs, saved_local_dgf;
 		int simplified_percentage;
 		bool programming_base_changed;
 		int previous_precision;
-		std::string custom_angle_unit;
+		std::string custom_angle_unit, default_currency;
 		QString custom_lang;
 		int rounding_mode;
 		int allow_multiple_instances;
 		int decimal_comma, dual_fraction, dual_approximation, auto_update_exchange_rates, title_type;
 		int completion_delay, expression_status_delay, auto_calculate_delay;
+		bool adaptive_autocalc_delay;
 		int completion_min, completion_min2;
 		QString style;
 		int palette;
@@ -283,8 +298,8 @@ class QalculateQtSettings : QObject {
 		bool format_result;
 		bool first_time;
 		bool enable_input_method;
-		bool use_custom_result_font, use_custom_expression_font, use_custom_keypad_font, use_custom_app_font;
-		bool save_custom_result_font, save_custom_expression_font, save_custom_keypad_font, save_custom_app_font;
+		bool use_custom_result_font, use_custom_expression_font, use_custom_keypad_font, use_custom_app_font, use_custom_status_font;
+		bool save_custom_result_font, save_custom_expression_font, save_custom_keypad_font, save_custom_app_font, save_custom_status_font;
 		QFont saved_app_font;
 		int replace_expression;
 		bool autocopy_result;
@@ -301,11 +316,11 @@ class QalculateQtSettings : QObject {
 		bool save_defs_on_exit, save_mode_on_exit, clear_history_on_exit;
 		int max_history_lines;
 		bool rpn_shown;
-		bool auto_calculate, status_in_history, autocalc_selection;
+		bool auto_calculate, status_in_history, status_in_statusbar, autocalc_selection;
 		int history_expression_type;
 		bool copy_ascii, copy_ascii_without_units;
 		bool close_with_esc;
-		std::string custom_result_font, custom_expression_font, custom_keypad_font, custom_app_font;
+		std::string custom_result_font, custom_expression_font, custom_keypad_font, custom_app_font, custom_status_font;
 		KnownVariable *vans[5], *v_memory;
 		MathStructure *current_result;
 		MathFunction *f_answer;
@@ -318,6 +333,7 @@ class QalculateQtSettings : QObject {
 		QByteArray datasets_geometry, datasets_vsplitter_state, datasets_hsplitter_state;
 		bool disable_cursor_blinking;
 		bool wayland_platform;
+		QStringList tempfiles;
 
 		int preserve_history_height;
 		bool keypad_appended, bases_appended;
